function [ret,phan]=Aqual2_findSpherePoleSpheres(phan,theory,verbose)
if ~exist('verbose','var')
    verbose=0;
end
ret=0;

filename=phan.filename; % used only for error handling

%propList={ 'Area', 'Centroid', 'BoundingBox','SubarrayIdx','PixelList','PixelIdxList'};
% Assume we don't know much other than where the center of the phantom  is to
% within a few mm
% make sure the SNR sphere has been found
if ~ isfield(phan,'voxCentroids')
    ret=1;
    estring=sprintf('searching for pole spheres -- SNR assumed to be have been found but no record of it?');
    Aqual2_writeFailureLog(phan.outputFilePrefix,estring);
end
origin=phan.voxCentroids(theory.SNRSphereIndex,1:3);

radius=7.5;
templateRadius=radius+3;
voxSize=phan.hdr.dime.pixdim(2:4);
[x,y,z]=meshgrid(-templateRadius:voxSize(2):templateRadius,...
    -templateRadius:voxSize(1):templateRadius,...
    -templateRadius:voxSize(3):templateRadius);
T = sqrt ( x.^2 + y.^2 + z.^2 ) < radius;
ST = size ( T );
% correlation is in fact 2D here but carried out slicewise over 3D image
% volume
if(verbose>1)
    disp('finding correlation image');
    tic;
end
corrImg= PMNormalizedCorrelation3d ( phan.img, T(:,:,round(ST(3)/2)) );
if(verbose>1)
    toc;
end
corrThresh=0.9;  % starting value
plausibleClusters=0;

voxSizes=[phan.hdr.dime.pixdim(3),...
    phan.hdr.dime.pixdim(2),...
    phan.hdr.dime.pixdim(4)];
% voxSizes will be run against the coordinates from regionprops
% so we have to swap x,y.
targetVolume=theory.Spheres(2).Volume/phan.voxelVolume;
if(verbose>1)
    disp('searching for pole spheres from seeds in correlation image');
end
 rad=zeros(20);
while ((plausibleClusters<2) && (corrThresh>0.7))
    plausibleClusters=0;
    labels=bwlabeln(corrImg>corrThresh);
    % go cheap -- we only need to know where the centroids are
    % area doesn't tell us anything, for example
    props=regionprops(labels,'Centroid');
    % now check to see if there are atleast two clusters in the props
    if(length(props)>1)
        % there are enough candidates; see if they are about the right
        % distance from the SNR sphere
        for i=1:length(props)
            delta=[props(i).Centroid(2)-origin(1),...
                props(i).Centroid(1)-origin(2),...
                props(i).Centroid(3)-origin(3)];
            delta=delta.*voxSizes;
            delta=delta.^2;
            rad(i)=sqrt(sum(delta));
        end
        nearSeeds=find(abs(rad-60)<10);
        farSeeds=find(abs(rad-90)<10);
        [phan,plausibleClusters]=seedsToSphere(phan,plausibleClusters,props,nearSeeds,2,targetVolume,radius,T) ;
        [phan,plausibleClusters]=seedsToSphere(phan,plausibleClusters,props,farSeeds,3,targetVolume,radius,T) ;
        if(plausibleClusters<2)
            % this might problem -- but we may recover
            estring=sprintf('searching for pole spheres: had to lower correlation coefficient: was %d ',corrThresh);
            disp(estring);
            corrThresh=corrThresh-0.05;
        end

        if(corrThresh<0.7)
            ret=1;
            estring=sprintf('searching for pole spheres: correlation is too low -- giving up ');
            disp(estring);
            Aqual2_writeFailureLog(phan.outputFilePrefix,estring,phan);
            return;
        end
    end;
end;
%ret=0;
return;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%5
function [phan,plausibleClusters]=seedsToSphere(phan,plausibleClusters,props,inSeeds,label,targetVolume,radius,template)
%[seeds,order]=sort(inSeeds);
%   clear seeds;
% now  props(order(i)) contains th e place we want to look
bestVec=[];
bestArea=0;
bestDefect=100*targetVolume;  % a bogus and large value
%bestIndex=0;
bestRegionLabelImg=[];
for i=1:length(inSeeds)
    [regionImg,subIdx]=getClippedSubRegion(phan,radius.*1.2,props(inSeeds(i)));
    [p,regionLabelImg]=getProps(regionImg);
    % now if p has more than one region, we have to find good one
        for j=1:length(p)
            pp=p(j);
            if abs(pp.Area-targetVolume)<bestDefect
                bestDefect=abs(pp.Area-targetVolume);
                [junk,bestVec]=GetSubImageIndex(subIdx,0,size(phan.img));
                clear junk;
                bestArea=pp.Area;
  %              bestIndex=inSeeds(i);
                bestRegionLabelImg=(regionLabelImg==j);
            end
        end
end
% now put a  window on best* and scribble it down if it's good
% enough (+-25%)
if (abs(bestArea-targetVolume)/targetVolume)<0.25
    plausibleClusters=plausibleClusters+1;
    % now set the m asks in phan.masterLabelImage
    sz=size(bestRegionLabelImg);
    for ii=1:sz(1)
        for jj=1:sz(2)
            for kk=1:sz(3)
                phan.masterLabelImg(ii+bestVec(1)-1,jj+bestVec(2)-1,kk+bestVec(3)-1)=...
                    label*bestRegionLabelImg(ii,jj,kk);
            end
        end
    end
    % now take bestRegionLabelImg and dilate it to get a background
    % sample
    nhood=ones(3,3,3);
    se=strel(nhood);
    clear nhood;
    tmpMask=imdilate(bestRegionLabelImg,se);
    tmpMask=imdilate(tmpMask,se);
    tmpbkgd=imdilate(tmpMask,se);
    tmpbkgd=imdilate(tmpbkgd,se);
    tmpbkgd=tmpbkgd-tmpMask;
 %   	disp('finding background');

    phan.backgroundIntensityMedian(label)=median(regionImg(tmpbkgd>0));
    
    % get the position information for this cluster
    phan=findObjectPositions(phan,label);
% now extract a new region around the phan.voxCentroids(label,1:3) area
    % and run 3D normalized cc on it.
    prop=struct('Centroid',...
        [phan.voxCentroids(label,2),phan.voxCentroids(label,1),phan.voxCentroids(label,3)]);    
    [regionImg,subIdx]=getClippedSubRegion(phan,radius.*1.8,prop);
     cimg=normxcorr3(template,regionImg,'same');
     
     cimgMaxInd=find(cimg(:)==max(cimg(:)));
    [cimgMaxSub(1),cimgMaxSub(2),cimgMaxSub(3)]=ind2sub(size(cimg),cimgMaxInd);
    % now use correlation weighted average over 5x5x5 cube centered on the
    %cimgMaxSub
    % do the dumb thing and do a triple nested loop; more matlab-ly
    % approaches I've tried are slower.
    cimgPos=[0,0,0];
    cimgSum=0;
    nInSum=0;
    window=2;
    [imax,jmax,kmax]=size(regionImg);
    try
        ilow=cimgMaxSub(1)-window;
        if(ilow<1)
            ilow=1;
        end

        ihigh=cimgMaxSub(1)+window;
        if(ihigh>imax)
            ihigh=imax;
        end

        jlow=cimgMaxSub(2)-window;
        if(jlow<1)
            jlow=1;
        end

        jhigh=cimgMaxSub(2)+window;
        if(jhigh>jmax)
            jhigh=jmax;
        end

        klow=cimgMaxSub(3)-window;
        if(klow<1)
            klow=1;
        end

        khigh=cimgMaxSub(3)+window;
        if(khigh>kmax)
            khigh=kmax;
        end


        for ii=ilow:ihigh
            for jj=jlow:jhigh
                for kk=klow:khigh
                    if(cimg(ii,jj,kk)>0)
                        nInSum=nInSum+1;
                        cimgSum=cimgSum+cimg(ii,jj,kk);
                        cimgPos(1)=cimgPos(1)+ii*cimg(ii,jj,kk);
                        cimgPos(2)=cimgPos(2)+jj*cimg(ii,jj,kk);
                        cimgPos(3)=cimgPos(3)+kk*cimg(ii,jj,kk);
                    end
                end
            end
        end
    catch
        disp('bad bad oob bug in findSpherePoleSpheres');
    end
    phan.nCorrPosElements(label)=nInSum;
    cimgPos=cimgPos./cimgSum;
    phan.corrPositions(label,1:3)=cimgPos+[subIdx{1}(1),subIdx{2}(1),subIdx{3}(1)]-[1,1,1];
   % cimgSize=size(cimg);
    %   imshow(cimg(:,:,floor(cimgSize(3)/2)));
    tmp=[phan.corrPositions(label,1:3),1];
    tmp=phan.RAS*tmp';
    phan.RAScorrPositions(label,1:3)=tmp(1:3)';
    phan.foundSphere(label)=1;
 end
return;
end
