function [ret,phan]=Aqual2_makePlots(phan,theory,verbose)

  ret=0 ;  % all is well unless we say otherwise
if ~exist('phan', 'var')
  ret=-1;
  disp('Aqual2_makePlots requires phantom image and theory structs');
end
if ~exist('theory', 'var')
  ret=-1;
  disp('Aqual2_makePlots requires phantom image and theory structs');
end

% if ~exist('outputFilename','var')
%   % fake an output name from phan.fileprefix
%   outputFilename=sprintf('%s_aqual2.pdf',phan.outputFilePrefix);
% end

if ~exist('verbose','var')
  verbose=0;
end

% find the list of spheres with foundSphere set 
goodSphereIndices=find(phan.foundSphere>0);

obsSpherePositions=phan.RASPositions(goodSphereIndices,:);
thSpherePositions=[theory.Spheres.CenterRAS]';
thSpherePositions=thSpherePositions(goodSphereIndices,:);

intensityRatio=phan.intensityMean(goodSphereIndices)./ ...
    phan.backgroundIntensityMedian(goodSphereIndices);
intensityRatio=intensityRatio(isfinite(intensityRatio));


OPP=OrthogonalProcrustes(obsSpherePositions',thSpherePositions');
if det(OPP)<0 
  disp(['warning: in Aqual2_makePlots Orthogonal Procustes introduced' ...
	' a flip?']);
end
OPPTForm=maketform('affine',OPP');
theoryLocs=tformfwd(thSpherePositions,OPPTForm);
delta=obsSpherePositions-theoryLocs;

close all;
figure ( figure('Position',[1 1 1600 1600]) )
clf;

tmp=min(theoryLocs,obsSpherePositions);  % does component by
                                         % component comparison
ymin=min(tmp); % find the global minimum over first dimension
               % (e.g. sphere number)
tmp=max(theoryLocs,obsSpherePositions);
ymax=max(tmp);
ymin=ymin-5.0;
ymax=ymax+5.0;
% now ymin and ymax are 1x3 matrices which tell us the y-extent of
% plots we will be making
% now do the same thing for x's
xmin=min(delta);
xmax=max(delta);
rangemax=max(xmax,-1*xmin);
xmin=min(-rangemax,[-2,-2,-2]);
xmax=max(rangemax,[2,2,2]);
ax=[xmin(1),xmax(1),ymin(1),ymax(1)];
subplot(4,3,1); plot(delta(:,1),obsSpherePositions(:,1),'r*'); 
xlabel( '\DeltaR/L' ); ylabel ( 'R/L' ); axis(ax); grid;
ax=[xmin(1),xmax(1),ymin(2),ymax(2)];
subplot(4,3,4); plot(delta(:,1),obsSpherePositions(:,2),'r*');
xlabel( '\DeltaR/L' ); ylabel ( 'A/P' ); axis(ax); grid;
ax=[xmin(1),xmax(1),ymin(3),ymax(3)];
subplot(4,3,7); plot(delta(:,1),obsSpherePositions(:,3),'r*'); 
xlabel( '\DeltaR/L' ); ylabel ( 'I/S' ); axis(ax); grid;

ax=[xmin(2),xmax(2),ymin(1),ymax(1)];
subplot(4,3,2); plot(delta(:,2),obsSpherePositions(:,1),'r*'); 
xlabel( '\DeltaA/P' ); ylabel ( 'R/L' ); axis(ax); grid;
ax=[xmin(2),xmax(2),ymin(2),ymax(2)];
subplot(4,3,5); plot(delta(:,2),obsSpherePositions(:,2),'r*');
xlabel( '\DeltaA/P' ); ylabel ( 'A/P' ); axis(ax); grid;
ax=[xmin(2),xmax(2),ymin(3),ymax(3)];
subplot(4,3,8); plot(delta(:,2),obsSpherePositions(:,3),'r*'); 
xlabel( '\DeltaA/P' ); ylabel ( 'I/S' ); axis(ax); grid;

ax=[xmin(3),xmax(3),ymin(1),ymax(1)];
subplot(4,3,3); plot(delta(:,3),obsSpherePositions(:,1),'r*'); 
xlabel( '\DeltaS/I' ); ylabel ( 'R/L' ); axis(ax); grid;
ax=[xmin(3),xmax(3),ymin(2),ymax(2)];
subplot(4,3,6); plot(delta(:,3),obsSpherePositions(:,2),'r*');
xlabel( '\DeltaS/I' ); ylabel ( 'A/P' ); axis(ax); grid;
ax=[xmin(3),xmax(3),ymin(3),ymax(3)];
subplot(4,3,9); plot(delta(:,3),obsSpherePositions(:,3),'r*'); 
xlabel( '\DeltaS/I' ); ylabel ( 'I/S' ); axis(ax); grid;


subplot(4,3,10); hist(intensityRatio,200);
xlabel('sphere contrast to bkgd ratio');
% now write the title and information into a subplot at the bottom
% of the figure
subplot(4,3,11);
axis('off');
axis([0 100 0 100])  % just to set up a coordinate system for our
                     % text
set(gcf,'DefaultTextColor','black')
txt=sprintf('Aqual2 output: executed by %s',getenv('USER'));		     
text(0,90,txt);
txt=sprintf('current time is  %s',datestr(now));
text(0,70,txt);
tmpfile=phan.fileprefix;
% title treats input like latex, eliminate and _'s since
% those would drop next char to subscript level
tidx=strfind(tmpfile,'_');
tmpfile(tidx)=' ';
txt=sprintf('input: %s',tmpfile);
text(0,50,txt);
if length(find(phan.foundSphere>0))<160
  set(gcf,'DefaultTextColor','red')
end
txt=sprintf('found %d position spheres (expected 160)',length(find(phan.foundSphere>0)));
text(0,30,txt);
PDFFilename=sprintf('%s_aqual2.pdf',phan.outputFilePrefix);
%! sleep 10;
try
    print(gcf,'-dpdf',PDFFilename);
catch
  try % try again
    print(gcf,'-dpdf',PDFFilename);
  catch
    disp('Cannot print figure to pdf trying ps file ');
    try 
      print(gcf,'-dps',PDFFilename);
    catch
        disp('CANNOT PRINT FIGURE');
    end 
  end
end
set(gcf,'DefaultTextColor','black'); 
if verbose <2
    close all;
end
return;

