function ADNIExampleNew
% This is a simple example of how to run the ADNI calibration
% phantom segmentation code.  No inputs are required, but the user will be
% prompted for them. 
% 
% Note: 
%
% Currently, this function just processes a single DICOM series at a time.
% Modifications to accept multiple Series are planned.
% 
% Latest Revision: 
% June 7th, 2005
%
% updated by Matt Senjem
% senjem.matthew1@mayo.edu
%
% added file/dir selection dialogs, and a few other things.
%
% Modified from ADNIExample.m (Dan Blezek)

Baseline = [];

% prompt user for inputs
[FileList,DICOMdir] = selectDICOMfiles('dicom');
outputdir = uigetdir(pwd, 'Select output folder');

% clean up figures
drawnow;

% reassure user that something is happening
disp('loading DICOM series ... this may take awhile.')

[Image, Headers] = LoadDICOMSeries ( DICOMdir, 0, 0, FileList );

% Get SubjectID and Series Number from DICOM header
Subject = Headers(1).PatientID;
Series  = Headers(1).SeriesNumber;

  % [Image, Headers] = LoadDICOMSeriesFast ( Pattern );

  % Segment the spheres
  [Spheres LI] = SegmentSpheresADNI ( Headers, Image, [], 1 );
  Spheres.SNR = CalculateSNRFromSphere ( Image, LI == Spheres.SNRSphereIndex );
  
  disp ( sprintf ( 'Subject: %s Series: %d', Subject, Series ) );
  
  if isempty ( Baseline )
          [ADNIdir,nam,ext,ver] = fileparts(mfilename);
      try
          load(fullfile(ADNIdir,'Baseline.mat'))
      catch
          Baseline = Spheres;
          disp(' ')
          disp(' ')
          disp(['WARNING!! - not found: ',fullfile(ADNIdir,'Baseline.mat')])
          disp('using this Series as the Baseline')
          save(fullfile(ADNIdir,'Baseline.mat'))
          disp(' ')
          disp(['saved to: ',fullfile(ADNIdir,'Baseline.mat')])
          disp(' ')
      end
  end
  
  try
    % If the segmentation failed it will show up here when we try
    % to reorder the spheres, hence the try-catch blocks.
    [FollowUp, LI, Mapping] = ReorderSpheres ( Baseline, Spheres, LI );
    Spheres = FollowUp;
    ADNIReport ( Baseline, FollowUp );
  catch 
    display ( sprintf ( 'Failed: %s Series: %d', Subject, Series ) );
  end
  
  % Save the image and ObjectMap

  FN = fullfile(outputdir,[Subject,'-',num2str(Series)]);
  
  % if this file already exists, change the name.
  nn=0;
  while ~isempty(dir([FN,'*']))
      
      nn=nn+1;
      FN = fullfile(outputdir,[Subject,'-',num2str(Series),'_',num2str(nn)]);
  end
  ADNISaveAnalyze ( FN, Headers, Image, Spheres, LI )
  disp(['saved to: ',FN,'.avw'])
  disp(['saved to: ',FN,'.obj'])


% Load the last segmented objectmap to verify that all is the
% same
ObjectMap = LoadAVWObjectMap ( [FN '.obj'] );
LabelMap = ObjectMap.Image;
[Spheres LI] = SegmentSpheresADNI ( Headers, Image, LabelMap > 1, 1 );
Spheres.SNR = CalculateSNRFromSphere ( Image, LI == Spheres.SNRSphereIndex );

disp ( sprintf ( 'Validation of SNR calculation: %f', Spheres.SNR ) );
disp ( sprintf ( 'Validation of Sphere locations (should be 0.0):' ) );
[Spheres] = ReorderSpheres ( Baseline, Spheres );
ADNIReport ( FollowUp, Spheres );

