function Line = ADNIReport ( Headers, Image, Baseline, FollowUp, Comment )
% function Line = ADNIReport ( Headers, Image, Baseline, FollowUp, Comment )
% Return a CSV line holding information about this scan.  In the
% future, the Baseline scan will not be necessary.
% If no arguments are given, return a CSV header to start the
% report.

if ~exist ( 'Headers', 'var' )
  Line = 'SubjectID, Date, Exam, Series, SeriesDescription, Scanner, Comment, SNR, XScale, YScale, ZScale, Mean Sphere Displacement, Max Sphere Displacement';
  return
end

if ~exist ( 'Comment', 'var' )
  Comment = '';
end

Header = Headers(1);
Line = [];
% Add info from the scan
Line = sprintf ( '%s', Header.PatientID );
Line = sprintf ( '%s,%s', Line, Header.StudyDate );
Line = sprintf ( '%s,%s', Line, Header.StudyID );
Line = sprintf ( '%s,%d', Line, Header.SeriesNumber );
Line = sprintf ( '%s,%s', Line, Header.SeriesDescription );
if isfield ( Header, 'StationName' )
  Line = sprintf ( '%s,%s', Line, Header.StationName );
else
  Line = sprintf ( '%s,%s', Line, 'Unknown Scanner' );
end
Line = sprintf ( '%s,%s', Line, Comment );



  
  
% SNR

Line = sprintf ( '%s,%f', Line, FollowUp.SNR );
  
% Now determine the scaling factor for each scan
Parameters = WarpDefaults;
Parameters.DoWarp = 0;
Parameters.SplineType = 'affine';

[NewImage, Results] = WarpPhantom ( [], PatientData(FollowUp.Header), Baseline, FollowUp, Parameters );
T = Results.Warp.tdata(2).tdata.T;

% Extract Scaling transform
Line = sprintf ( '%s,%f,%f,%f', Line, T(1,1), T(2,2), T(3,3) );

% Align the spheres using by minimizing the distances over all the
% spheres using the Procrustes algorithm
OPP = OrthogonalProcrustes ( [FollowUp.Spheres.CanonicalCOM], [Baseline.Spheres.CanonicalCOM] );
    
OPPTForm = maketform ( 'affine', OPP' );
    
BaselinePointsCan = tformfwd ( [Baseline.Spheres.CanonicalCOM]', OPPTForm );

% Find the differences
D = BaselinePointsCan - [FollowUp.Spheres.CanonicalCOM]';
D = sqrt ( sum ( D.^2, 2 ) );

Line = sprintf ( '%s,%f,%f', Line, mean(D), max(D) );


