function [D,sfac,sunit]=ADNIScatterPlots ( Baseline, Spheres, Headers, InputFileStub, PDFFilename )
% [Displacements,scaleFactors]=ADNIScatterPlots ( Baseline, Spheres, Headers, Filename )
%
% Create, and optionally save scatter plots of the sphere
% displacements in different directions (R/L, A/P, S/I).
% The notion of R/L, A/P and S/I is only as good as it is in your
% input  --- for DICOM input it's probably reasonable; for
% AnalyzeAVW that may not be the case 
% Baseline - absolute sphere locations in a "Spheres" structure,
% see SpherePositions.m
%
% Spheres - segmented spheres from a phantom scan
% Headers - DICOM headers for Spheres
% InputFileStub - optional text to be embedded in the figure for
% tracking purposes
% PDFFilename - optional filename for saving the plots
%  if PDFFilename ends in .ps then postscript is generated
%  otherwise create <PDFFilename>.pdf
%
% NOTE:::: FOR ADNI SITE QUALIFICATION USE 
% Baseline as result of spherePositions()
% And spheres as segmented from data
%  
  
theory = Baseline;
  
Parameters = WarpDefaults;Parameters.DoWarp = 0;Parameters.SplineType = 'affine';
[rtheory] = ReorderSpheres (Spheres, theory);
tmpmask=ones(1,length(Spheres.Spheres));
tmpmask(Spheres.CNRSphereIndex)=0;
tmpmask(Spheres.SNRSphereIndex)=0;
culledSpheres=Spheres;
culledSpheres.Spheres=culledSpheres.Spheres(tmpmask>0);
% now repeat for rtheory
tmpmask=ones(1,length(rtheory.Spheres));
tmpmask(rtheory.CNRSphereIndex)=0;
tmpmask(rtheory.SNRSphereIndex)=0;
culledRtheory=rtheory;
culledRtheory.Spheres=culledRtheory.Spheres(tmpmask>0);
clear tmpmask;
[NewImage, Results] = WarpPhantom ( [], PatientData(Headers), culledRtheory, culledSpheres, Parameters );
T = Results.Warp.tdata(2).tdata.T; 
sintheta=T(3,2);
costheta=sqrt(1-sintheta*sintheta);
sinphi=T(3,1)/costheta;
cosphi=sqrt(1-sinphi*sinphi);
sinpsi=-1.0 *T(1,2)/costheta;
cospsi=sqrt(1-sinpsi*sinpsi);
sfac=[T(1,1)/(cospsi*cosphi +sinphi*sinpsi*sintheta), 
      T(2,2)/(costheta*cospsi),
      T(3,3)/(costheta*cosphi)];
disp(sprintf('scale factors: %d, %d, %d',sfac))  
% now work it out by taking unit vectors in RAS space and tranforming them
% into the space of the theory phantom.  The lengths after that
% transformation are the factor by which the gradient amps need tweaked.
RASToCanTForm = maketform ( 'affine', culledSpheres.RASToCanonicalTransform' );
SpheresToTheoryTForm=Results.Warp.tdata(2);    
compositeTForm= maketform('composite',[SpheresToTheoryTForm,RASToCanTForm]);
unitVecs=eye(3,3);
originVecs=zeros(3,3);    
transformedUnitVecs=  tformfwd(unitVecs,compositeTForm);
transformedOriginVecs=  tformfwd(originVecs,compositeTForm);    
transformedDiffSq=(transformedUnitVecs-transformedOriginVecs).^2;
    
scaledVecs=sqrt(sum(transformedDiffSq));
sunit=scaledVecs;
disp(sprintf('scaled unitVectors: %d, %d, %d',scaledVecs))
OPP = OrthogonalProcrustes ( [culledRtheory.Spheres.CanonicalCOM], [culledSpheres.Spheres.CanonicalCOM] ); 
OPPTForm = maketform ( 'affine', OPP' );
BaselinePointsCan = tformfwd ( [culledSpheres.Spheres.CanonicalCOM]', OPPTForm );


BaselinePoints = [BaselinePointsCan];
BaselinePointsRAS = tforminv ( BaselinePointsCan, RASToCanTForm );

RTheoryPointsRAS = tforminv ( [culledRtheory.Spheres.CanonicalCOM]', RASToCanTForm );

D = BaselinePointsRAS - RTheoryPointsRAS;   
close all;
figure ( figure('Position',[1 1 1200 1200]) )
clf;
% now find min  and max BaselinePointsRAS in each dim
axmin=min(BaselinePointsRAS)-5.0;
axmax=max(BaselinePointsRAS)+5.0;

ax1=[-2,2,-110,110];ax1=[-2,2,axmin(1),axmax(1)];
ax2=[-2,2,axmin(2),axmax(2)];
ax3=[-2,2,axmin(3),axmax(3)];
if((min(D(:,1))<-2) || (max(D(:,1))>2))
ax1=[-3,3,axmin(1),axmax(1)];
ax2=[-3,3,axmin(2),axmax(2)];
ax3=[-3,3,axmin(3),axmax(3)];
end
 subplot(3,3,1); plot(D(:,1),BaselinePointsRAS(:,1),'r*'); xlabel ( '\DeltaR/L' ); ylabel ( 'R/L' ); axis(ax1); grid;
 subplot(3,3,4); plot(D(:,1),BaselinePointsRAS(:,2),'r*'); xlabel ( '\DeltaR/L' ); ylabel ( 'A/P' ); axis(ax2); grid;
 subplot(3,3,7); plot(D(:,1),BaselinePointsRAS(:,3),'r*'); xlabel ( '\DeltaR/L' ); ylabel ( 'I/S' ); axis(ax3); grid;

ax1=[-2,2,-110,110];ax1=[-2,2,axmin(1),axmax(1)];
ax2=[-2,2,axmin(2),axmax(2)];
ax3=[-2,2,axmin(3),axmax(3)];
if((min(D(:,2))<-2) || (max(D(:,2))>2))
ax1=[-3,3,axmin(1),axmax(1)];
ax2=[-3,3,axmin(2),axmax(2)];
ax3=[-3,3,axmin(3),axmax(3)];
end

 subplot(3,3,2); plot(D(:,2),BaselinePointsRAS(:,1),'r*'); xlabel ( '\DeltaA/P' ); ylabel ( 'R/L' ); axis(ax1); grid;
 subplot(3,3,5); plot(D(:,2),BaselinePointsRAS(:,2),'r*'); xlabel ( '\DeltaA/P' ); ylabel ( 'A/P' ); axis(ax2); grid;
 subplot(3,3,8); plot(D(:,2),BaselinePointsRAS(:,3),'r*'); xlabel ( '\DeltaA/P' ); ylabel ( 'I/S' ); axis(ax3); grid;
 
ax1=[-2,2,-110,110];ax1=[-2,2,axmin(1),axmax(1)];
ax2=[-2,2,axmin(2),axmax(2)];
ax3=[-2,2,axmin(3),axmax(3)];
if((min(D(:,3))<-2) || (max(D(:,3))>2))
ax1=[-3,3,axmin(1),axmax(1)];
ax2=[-3,3,axmin(2),axmax(2)];
ax3=[-3,3,axmin(3),axmax(3)];
end

subplot(3,3,3); plot(D(:,3),BaselinePointsRAS(:,1),'r*'); xlabel ( '\DeltaS/I' ); ylabel ( 'R/L' ); axis(ax1); grid;
subplot(3,3,6); plot(D(:,3),BaselinePointsRAS(:,2),'r*'); xlabel ( '\DeltaS/I' ); ylabel ( 'A/P' ); axis(ax2); grid;
subplot(3,3,9); plot(D(:,3),BaselinePointsRAS(:,3),'r*'); xlabel ( '\DeltaS/I' ); ylabel ( 'I/S' ); axis(ax3); grid;
%  

%  subplot(3,3,1); plot(D(:,1),BaselinePoints(:,1),'r*'); xlabel ( '\DeltaR/L' ); ylabel ( 'R/L' )
%  subplot(3,3,2); plot(D(:,2),BaselinePoints(:,1),'r*'); xlabel ( '\DeltaA/P' ); ylabel ( 'R/L' )
%  subplot(3,3,3); plot(D(:,3),BaselinePoints(:,1),'r*'); xlabel ( '\DeltaS/I' ); ylabel ( 'R/L' )
%  subplot(3,3,4); plot(D(:,1),BaselinePoints(:,2),'r*'); xlabel ( '\DeltaR/L' ); ylabel ( 'A/P' )
%  subplot(3,3,5); plot(D(:,2),BaselinePoints(:,2),'r*'); xlabel ( '\DeltaA/P' ); ylabel ( 'A/P' )
%  subplot(3,3,6); plot(D(:,3),BaselinePoints(:,2),'r*'); xlabel ( '\DeltaS/I' ); ylabel ( 'A/P' )
%  subplot(3,3,7); plot(D(:,1),BaselinePoints(:,3),'r*'); xlabel ( '\DeltaR/L' ); ylabel ( 'I/S' )
%  subplot(3,3,8); plot(D(:,2),BaselinePoints(:,3),'r*'); xlabel ( '\DeltaA/P' ); ylabel ( 'I/S' )
%  subplot(3,3,9); plot(D(:,3),BaselinePoints(:,3),'r*'); xlabel ( '\DeltaS/I' ); ylabel ( 'I/S' )
%  

% $$$  figure ( 2 )
% $$$ % subplot ( 2,2,1);
% $$$  plot ( RTheoryPointsRAS(:,1), RTheoryPointsRAS(:,2), 'g+' )
% $$$  hold on;
% $$$  plot ( BaselinePointsRAS(:,1), BaselinePointsRAS(:,2), 'ro' );
% $$$  title ( 'Axial' )
% $$$  figure ( 3 )
% $$$ % subplot ( 2,2,2);
% $$$  plot ( RTheoryPointsRAS(:,1), RTheoryPointsRAS(:,3), 'g+' )
% $$$  hold on;
% $$$  plot ( BaselinePointsRAS(:,1), BaselinePointsRAS(:,3), 'ro' );
% $$$  title ( 'Coronal' )
% $$$  figure ( 4 )
% $$$ % subplot ( 2,2,3);
% $$$  plot ( RTheoryPointsRAS(:,2), RTheoryPointsRAS(:,3), 'g+' )
% $$$  hold on;
% $$$  plot ( BaselinePointsRAS(:,2), BaselinePointsRAS(:,3), 'ro' );
% $$$  title ( 'Sagittal' )
% $$$  




disp(sprintf('std deviations:  %d, %d, %d',std(D)));
%save;
if exist('InputFileStub','var')
  subplot(3,3,1);
  tmpfile=InputFileStub;
  % title treats input like latex, eliminate and _'s since
  % those would drop next char to subscript level
  tidx=strfind(tmpfile,'_');
  tmpfile(tidx)=' ';
  title(tmpfile);
end


if exist ( 'PDFFilename', 'var' )
   subplot(3,3,1);
   %title(PDFFilename);
   psPattern='\.ps$';
   isPS=regexp(PDFFilename,psPattern);
   if ~isempty(isPS)
     print(gcf,'-dps',PDFFilename);
   else
     print(gcf, '-dpdf',PDFFilename);
   end
end
