function Im = LoadNiftiImage ( filename )
global noPermute; 
  
  
   if ~exist('filename','var'),
      error('Usage: [nii] = load_nii(filename, [img_idx], [old_RGB])');
   end
   
   if ~exist('img_idx','var'), img_idx = []; end
   if ~exist('old_RGB','var'), old_RGB = 0; end
    [nii.hdr,nii.filetype,nii.fileprefix,nii.machine] = load_nii_hdr(filename);
   
   %  Read the dataset body
   %
   [nii.img,nii.hdr] = ...
	load_nii_img(nii.hdr,nii.filetype,nii.fileprefix,nii.machine,img_idx,old_RGB);
    hdr=nii.hdr;
    if hdr.hist.qform_code > 0   
	   b = hdr.hist.quatern_b;
	   c = hdr.hist.quatern_c;
	   d = hdr.hist.quatern_d;
	   a = sqrt(1.0-(b*b+c*c+d*d));
       a=real(a);
	   qfac = hdr.dime.pixdim(1);
	   i = hdr.dime.pixdim(2);
	   j = hdr.dime.pixdim(3);
	   k = qfac * hdr.dime.pixdim(4);

	   R = [a*a+b*b-c*c-d*d     2*b*c-2*a*d        2*b*d+2*a*c
		2*b*c+2*a*d         a*a+c*c-b*b-d*d    2*c*d-2*a*b
	        2*b*d-2*a*c         2*c*d+2*a*b        a*a+d*d-c*c-b*b];

	   R = R * diag([i j k]);

	   T = [hdr.hist.qoffset_x
		hdr.hist.qoffset_y
            hdr.hist.qoffset_z];
        nii.RAS=[R T];
        nii.RAS(4,:)=[0 0 0 1 ]; 
      else
       error('Image is assumed to have a valid qform field --- this one does not');
    end
%nii=load_nii(FileName);
% now patch up the Headers with some redundant copies of fields
switch nii.hdr.dime.datatype
    case {1,32,64,128}
        warning('datatype not supported');
        % nb 1 exclude becase bit fields have to padded to byte boundaries
        % exclude other "bigger" data types
    case 2
        datatype='uchar';
        datasize=1;
        dataString='AVW_UNSIGNED_CHAR';
    case 4
        datatype='short';
        datasize=2;
        dataString='AVW_SIGNED_SHORT';
    case 8
        datatype='int32';
        datasize=4;
        dataString='AVW_SIGNED_INT';
    case 16
        datatype='float';
        datasize=4;
        dataString='AVW_FLOAT';
end

Im=struct('Image',0,'DataType',dataString,'Width',nii.hdr.dime.dim(2), ...
    'Height',nii.hdr.dime.dim(3),'Depth',nii.hdr.dime.dim(4),'NumVols',1, ...
    'VoxelWidth',nii.hdr.dime.pixdim(2),'VoxelHeight',nii.hdr.dime.pixdim(3), ...
    'VoxelDepth',nii.hdr.dime.pixdim(4),'Orientation','niftiRAS','niftiRASxform',nii.RAS);
Im.Image=cast(nii.img,'double');
    
%if(isempty(noPermute))
%   Im.Image=permute(Im.Image,[2,1,3]);
%end

 
return