function T = OrthogonalProcrustes ( D, M )
% T = OrthogonalProcrustes ( D, M )
% OrthogonalProcrustes finds the optimal transformation (Rotation,
% Translation) such that D = T M
% where D, M are 3,N vectors
  
% Find the centroid and subtract
  N = size ( D, 2 );
  DCentroid = sum ( D' )' / N;
  DC = D - repmat ( DCentroid, 1, N );
  
  MCentroid = sum ( M' )' / size ( M, 2 );
  MC = M - repmat ( MCentroid, 1, N );
  
  H = MC * DC';
  
  [U, S, V] = svd ( H );
  Rotation = V * U';
  Translation = DCentroid - Rotation * MCentroid;
  
  T = eye ( 4 );
  T(1:3,1:3) = Rotation;
  T(1:3,4) = Translation;
  
  
