function [SortedSpheres, LabeledImage, Mapping] = ReorderSpheres(Baseline, Calibration, LabeledImage)
% [SortedSpheres, LabeledImage] = ReorderSpheres ( Baseline, Calibration[, LabeledImage] )
% ReorderSpheres -- use the Hungarian algorithm to match spheres
% and reorder Calibration
%
% Match the spheres in canonical phantom space from the baseline to
% the phantom.  Reorder the spheres in the Calibration structure and
% return it.
%
% If LabeledImage is passed in, the labels are changed to reflect
% the reordered spheres

  if ~exist ( 'LabeledImage', 'var' )
    LabeledImage = [];
  end

% Compare
% S1 = [Calibration.Spheres.CenterRAS];
% S2 = [Baseline.Spheres.CenterRAS];



S1 = [Calibration.Spheres.CanonicalCOM];

if isempty ( Baseline )
  S2 = [];
else
  S2 = [Baseline.Spheres.CanonicalCOM];
end


u = size ( S1, 2 );
D = zeros(u,u);
for r = 1:u
  for c = 1:u
    foo = S1(:,r) - S2(:,c);
    D(r,c) = sqrt ( sum ( foo.^2 ) );
  end
end

[C,T] = Hungarian(D);

% C(J) = I means row I is assigned to column J
% in our case, S1 are the rows, S2 are the columns
% S1(C) matches with S2

% Re-order ReproducibilitySeries1
Calibration.Spheres = Calibration.Spheres(C);

% Just copy over the LandmarkSphereIndex from the Baseline
Calibration.LandmarkSphereIndex = Baseline.LandmarkSphereIndex;
Calibration.SNRSphereIndex = Baseline.SNRSphereIndex;
Calibration.CNRSphereIndex = Baseline.CNRSphereIndex;
Calibration.FiducialSphereIndex = Baseline.FiducialSphereIndex;


if ~isempty ( LabeledImage )
  [a,b] = sort ( C );
  LabeledImage(find(LabeledImage>0)) = b(LabeledImage(find(LabeledImage>0)));
end

S1 = [Calibration.Spheres.CanonicalCOM];
S2 = [Baseline.Spheres.CanonicalCOM];

DD = S1 - S2;
T1 = sum(D(logical(sparse(C,1:size(D,2),1))));
T2 = sum ( sqrt ( sum ( DD.^2 ) ) );

Calibration.MatchError = T2;
% disp ( sprintf ( 'Validation of the match: %f == %f', T1, T2 ) );
if T1 ~= T2
  warning ( sprintf ( 'Could not validate the match: %f ~= %f', T1, T2 ) );
end

SortedSpheres = Calibration;
Mapping = C;
  
% disp ( 'ReorderSpheres Sanity Check:' );
% disp ( sprintf ( '\tMaximum displacement: %f\n', max(D) ) );

