function Uout = TPSInverse ( X, T )
% TPSValue conforms to the INVERSE_FNC of maketform
% X is a P x D matrix, where D == 3
  
if isfield ( T, 'tdata' )
  W = T.tdata;
else
  W = T;
end

if W.BasisFunction ~= 'r2logr2'
  error ( sprintf ( 'Unknown basis function: %s', W.BasisFunction ) );
end


% X must be a P x D matrix, whose rows are points in the output
% space
[r,c] = size ( X );
if c ~= W.D
  error ( sprintf ( 'Expected points of dimension %d, but found %d', W.D, c ) )
end

% turn off warnings
WarningState = warning ( 'off' );

% Uout is P x D
Uout = zeros ( size ( X ) );
Param = struct([]);
Param(1).W = W;
Opts = [0.0001 0.001 0.001 10 0.5];

Delta = [0 0 0];
for row = 1:r
  In = X(row,:);
  % Param.Target = In;
  % [P info perf] = SMarquardt ( @TPSInverseMetricSMarquardt, Param, In, Opts );
  % [P foo flag output] = fminunc ( @TPSInverseMetric, In, [], W, In );
  [P Delta] = TPSInverseInternal ( In + Delta, W, In );
  Uout(row,:) = P;
end
  
warning ( WarningState );

function [P, Delta] = TPSInverseInternal ( X, W, Target )
% Use a very simple gradient descent
  P = X;
  Delta = Target - TPSValue ( P, W );
  Iteration = 0;
  while norm ( Delta ) > 0.005
    Delta = Target - TPSValue ( P, W );
    P = P + Delta./2.0;
    if Iteration > 100
      error ( 'Failed to converge' )
    end
    Iteration = Iteration + 1;
  end
    

function D = TPSInverseMetricSMarquardt ( X, Param )
  Uout = TPSValue ( X', Param.W );
  D = Uout - Param.Target;
  D = sum ( D.^2 );

function D = TPSInverseMetric ( X, W, Target )
% Distance = Foo ( X, W, Target )
% Returns the squared distance from TSPValue(X) to the Target
Uout = TPSValue ( X, W );
D = Uout - Target;
D = sum ( D.^2 );


