function Uout = TPSValue ( X, T )
% TPSValue conforms to the FORWARD_FNC of maketform
% X is a P x D matrix, where D == 3
  
if isfield ( T, 'tdata' )
  W = T.tdata;
else
  W = T;
end


switch lower ( W.BasisFunction )
 case 'ebs'
 case 'ebrs'
 case 'tps'
 case 'vs'
 otherwise
  error ( sprintf ( 'Unknown basis function: %s', W.BasisFunction ) );
end


% X must be a P x D matrix, whose rows are points in the output
% space
[r,c] = size ( X );
if c ~= W.D
  error ( sprintf ( 'Expected points of dimension %d, but found %d', W.D, c ) )
end

mUW = mTPSValue ( W.P', W.Weights, X', W.BasisFunctionNumber, W.Alpha );

% Uout is P x D
M = W.ARotation;
C = W.ATranslation;

% Do the affine part as well
Uout = M * X' + mUW;
Uout = Uout' + X;

for ii = 1:W.D
  Uout(:,ii) = Uout(:,ii) + C(ii);
end
% Uout(:,1) = Uout(:,1) + C(1);
% Uout(:,2) = Uout(:,2) + C(2);
% Uout(:,3) = Uout(:,3) + C(3);
return

