function [Parameters] = WarpDefaults ( varargin )
% WarpDefaults - returns default parameters for WarpPhantom
%
% Settings are
% InterpolationMethod (default: 'linear')
%     -- How to interpolate the warped image
%        options are 'linear', 'cubic', 'nearest'
%        The function 'CreateHannSincKernel' will generate a windowed sinc kernel.
%        see the documentation for 'makeresampler' for other forms.
% PadMethod (default: 'replicate')
%     -- How to pad the interpolated image, see 'makeresampler' for options.
% SplineType (default: 'tps')
%     -- Deformation type to use (see 'TPS'), options are:
%        'tps':  Thin Plate Spline
%        'vs':   Volume Spline
%        'ebs':  Elastic Body Spline
%        'ebrs': Elastic Body Reciprocal Spline
%        'affine': Calculate the affine transform
% Alpha (default: 8)
% Stiffness (default: 0.0)
%     -- optional spline parameters (see 'TPS')
%
% <Optional or Testing Settings>
% 
% DoWarp (default: 1)
%     -- flag to indicate if the warp should actually be computed, if set to zero no
%        warp or interpolation is done
% PrintWarpTime (default: 0)
%     -- calculate and print time required to warp
% SliceNumber (default: -1)  
%     -- Which slice to interpolate, -1 is all slices
% CalculateIsosurface (default: 0)
%     -- calculate the volume of a spherical phantom, not need except for testing
% CalculateVolume (default: 0)
%     -- calculate the volume of the spherical phantom, not needed except for testing

Parameters = struct ( 'SliceNumber', -1, ...
                      'InterpolationMethod', 'linear', ...
                      'PadMethod', 'replicate', ...
                      'SplineType', 'tps', ...
                      'Alpha', 8, ...
                      'Stiffness', 0.0, ...
                      'CalculateIsosurface', 0, ...
                      'DoWarp', 1, ...
                      'PrintWarpTime', 0, ...
                      'CalculateVolume', 0 );
