% Warp a square into a circle

Square = zeros ( 256, 256, 1 );
b = 100;
a = b-50;
c = b+50;
s = a:c;
Square(s,s) = 100;

% Correspondances, the square is the calibration space, the sphere
% is the baseline space

Calibration = [a a; 
               b a;
               c a;
               c b;
               c c;
               b c;
               a c;
               a b;];

figure ( 1 ); clf;
imagesc ( Square );
[C,R,P] = impixel;

Calibration = [R C];

for ii = 1:size(Calibration,1)
  Square ( Calibration(ii,1), Calibration(ii,2) ) = 500;
end

Angles = DToR ( [0:45:360]' );
Radius = 80;
[xx, yy] = meshgrid ( 1:256, 1:256 );

CC = (sqrt((xx-b).^2+(yy-b).^2) < Radius) * 100;
figure ( 1 ); clf;
imagesc ( CC );
[C,R,P] = impixel;
Baseline = [Radius*cos(Angles)+b, Radius*sin(Angles)+b];

Baseline = [R C];



W = TPS ( Baseline', Calibration', 2 );
Warp = maketform ( 'custom', 2, 2, [], @TPSValue, W );
R = makeresampler ( 'cubic', 'fill' );

Circle = tformarray ( Square, Warp, R, [1 2], [2 1], size(Square), [], 0 );

for ii = 1:size(Baseline,1)
  % Circle ( round(Baseline(ii,1)), round(Baseline(ii,2)) ) = 700;
end


figure(1); clf;
imagesc ( Square );
hold on
line ( Baseline(:,1), Baseline(:,2) );
plot ( a, a, '+g' )

% Plot our vectors
Diff = Baseline - Calibration;
quiver ( Calibration(:,1), Calibration(:,2), Diff(:,1), Diff(:,2), 0 )

% Draw grid lines
s = size ( Circle );
[xx,yy] = meshgrid ( 1:40:s(1), 1:40:s(2) );
pt = [xx(:) yy(:)];
pt = tforminv ( pt, Warp );
xx = reshape ( pt(:,1), size(xx) );
yy = reshape ( pt(:,2), size(yy) );
hold on
foo = line ( xx, yy, 'Color', [0 1 0] );
foo = line ( xx', yy', 'Color', [0 1 0] );
hold off

figure ( 2 ); clf;
imagesc ( Circle )
hold on
quiver ( Calibration(:,1), Calibration(:,2), Diff(:,1), Diff(:,2), 0 )
