%Legendre Sperhical harmonic calculation
%   h = sphericalHarmonics(n,m,type) calculates the spherical harmonics of
%                                    degree n and order m. The default type
%                                    is the cosine (type = 'c') but type can also
%                                    be specified as sine (type = 's');
%                                    Use 'cart' to specify (x,y,z)
%                                    cartesian coordinates.
%                                    Use 'spher' to specify (r,theta,phi)
%                                    Spherical coordinates
%
%   Copyright 2002  GE Medical Systems
%             Jason A. Polzin
function h = sphericalHarmonics(n,m,type,space)
if (nargin == 2)
    type = 'c';
end

if (nargin < 4)
    space = 'cart'; 
end

if (m > n) 
    error('m cannot be greater than n');
end

syms d;
%maple('with','orthopoly');
%Plegn = maple('P', n, d);
% Both lines are equivalent 
dPlegnm  = associatedLegendrePolynomial(d,n,m);

syms theta;
if type == 'c'
    q = cos(m*theta);
elseif type == 's'
    q = i * sin(m*theta);
end
%q = exp(j*theta);

syms r phi;
%Spherical Harmonics
h = r^n * q * dPlegnm;
%Substitute cos(phi) for d
h = subs(h, d, cos(phi));
% Substitute cos^2(phi) + sin^2(phi) = 1
h = subs(h, cos(phi)^2, 1-sin(phi)^2);
h = simple(h);
try
    h = expand(h);
catch
end
if (strcmp(space, 'cart'))
    
    syms x y z;
    % Substitute, r * cos(phi) = z
    % Substitute, r * cos(theta) = x
    % Substitute, r * sin(theta) = y
    h = subs(h,cos(phi), z/r);
    h = subs(h,cos(theta), x/(r * sin(phi)));
    h = subs(h,sin(theta), y/(r * sin(phi)));
    try
        h = expand(h);
    catch
    end
    %Substitute r * sin(phi) = sqrt(x^2 + y^2)
    h = subs(h,sin(phi), sqrt(x^2 + y^2)/r);
    %Substitute r^2 = x^2 + y^2 + z^2
    h = subs(h,r, sqrt(x^2 + y^2 + z^2));
    try
        h = expand(h);
    catch
    end
end

function p = legendrePolynomial(x,n)
p = diff((x^2 - 1)^n, x, n) / (2^n * factorial(n));

function p = associatedLegendrePolynomial(x,n,m)
p = (-1)^m * (1-x^2)^(m/2) * diff(legendrePolynomial(x,n), x, m);
