function [level,em] = OtsuThreshold ( I, optLowerThresh )
% Probably liberated from graythresh.m by D. Blezek 
% level is similar to graythresh output only not scaled 
% to range [0,1]; also graythresh works in only 256 bins;
% this works using bins to span the full range of the data
% with unit binsize
% Modified 29 Jun 2006 by Jeff Gunter to provide effectiveness as a 
% return value.
% One input argument required.
% Convert all N-D arrays into a single column.  Convert to uint8 for
% fastest histogram computation.
% I = im2uint8(I(:));
  
I = I(:);
if exist('optLowerThresh','var')
   keep=find(I>optLowerThresh);
   I=I(keep);
    if isempty(I)
        disp('in OtsuThreshold: no data above optLowerThreshold');
    end
end
counts = histc ( I, -.5:1:max(I)+.5 );
counts = counts';
num_bins = length ( counts );
% Variables names are chosen to be similar to the formulas in
% the Otsu paper.
p = counts / sum(counts);
omega = cumsum(p);
mu = cumsum(p .* (1:num_bins));
mu_t = mu(end);

% Save the warning state and disable warnings to prevent divide-by-zero
% warnings.
state = warning;
warning off;
sigma_b_squared = (mu_t * omega - mu).^2 ./ (omega .* (1 - omega));

% Restore the warning state.
warning(state);

% Find the location of the maximum value of sigma_b_squared.
% The maximum may extend over several bins, so average together the
% locations.  If maxval is NaN, meaning that sigma_b_squared is all NaN,
% then return 0.
% plot ( sigma_b_squared )
maxval = max(sigma_b_squared);
if isfinite(maxval)
    idx = mean(find(sigma_b_squared == maxval));
    
    % Normalize the threshold to the range [0, 1].
    % Nope, don't normalize!
    % level = (idx - 1) / (num_bins - 1);
    level = mean ( idx ) + min(I) - 1;
else
    level = 0.0;
end

if nargout > 1
  if isfinite(maxval)
    em = maxval/(sum(p.*((1:num_bins).^2)) - mu_t^2);
  else
    em = 0;
  end
end
